package ca.canadapost.cpcdp.returns;

import ca.canadapost.cpcdp.returns.stub.openreturn.*;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.frontend.ClientProxy;
import ca.canadapost.cpcdp.returns.util.ClientUtil;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.soap.SOAPFaultException;
import java.util.Map;

/**
 * Sample code for the DeleteOpenReturnTemplate Canada Post service.
 * <p>
 * The DeleteOpenReturnTemplate service is used to delete an existing active open
 * return template.
 * <p>
 * This sample is configured to access the Developer Program sandbox environment.
 * Use your development key username and password for the web service credentials.
 */
public class DeleteOpenReturnTemplateClient {
    // Main class for local testing only
    public static void main(String[] args) {
        try{
            // Your username, password and customer number are imported from the following file: CPCWS_SOAP_Returns_Java_Samples/user.properties
            Map<String, String> userProperties = ClientUtil.getUserProperties("user.properties");
            String username = userProperties.get("username");
            String password = userProperties.get("password");
            String mailedBy = userProperties.get("mailedBy");

            OpenReturnService service = new OpenReturnService();
            OpenReturnPortType port = service.getOpenReturnPort();

            //set endpoint
            Map ctx = ((BindingProvider) port).getRequestContext();
            ctx.put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, "https://ct.soa-gw.canadapost.ca/rs/soap/openreturn/v2");

            //wss4j interceptor -  add UsernameToken to soap header
            Client client = ClientProxy.getClient(port);
            client.getOutInterceptors().add(ClientUtil.getUsernameTokenInterceptor(username, password));

            //create request
            DeleteOpenReturnTemplateRequest request = new DeleteOpenReturnTemplateRequest();
            request.setLocale("FR");
            request.setMailedBy(mailedBy);
            request.setTemplateId("826131401817581405");

            //execute request
            DeleteOpenReturnTemplateResponse response = port.deleteOpenReturnTemplate(request);

            //retrieve values from response
            if(response.getMessages() == null){
                if(response.isDeleteTemplateSuccess()){
                    System.out.println("Template successfully deleted.");
                } else {
                    System.out.println("Template not deleted.");
                }
            } else {
                // Assume Error
                for(Messages.Message m : response.getMessages().getMessage()){
                    System.out.println("Error Code: " + m.getCode());
                    System.out.println("Error Message: " + m.getDescription());
                }
            }
        }
        catch (SOAPFaultException e) {
            System.out.println("Fault Code: " + e.getFault().getFaultCode());
            System.out.println("Fault Reason: " + e.getFault().getFaultString());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
